==> customer-link-project-api-0.0.25-20221213.014402-8-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app86760/dto/AddPointsAndPayOrderDTO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app86760.dto;

import com.alibaba.fastjson.annotation.JSONField;

/**
 * write_your_class_description_here
 *
 * @author xulei
 * @since 1.0.0
 */
public class AddPointsAndPayOrderDTO extends BaseDTO {

    /**
     * 交易类型 <br>
     * 必须
     */
    @JSONField(name = "transtypeno")
    private String transTypeNo = "4018";

    /**
     * 奖品类型: 苏银豆为1, 虚拟卡为2, 实物为3 <br>
     * 必须
     */
    @JSONField(name = "awardType")
    private String awardType;

    /**
     * 交易金额 <br>
     * awardType=1时, 需传参
     */
    @JSONField(name = "pointsamount")
    private String pointsAmount;

    /**
     * 摘要 <br>
     * 必须
     */
    @JSONField(name = "description")
    private String description;

    /**
     * 省 <br>
     * awardType=3时, 需传参
     */
    @JSONField(name = "provincename")
    private String provinceName;

    /**
     * 市 <br>
     * awardType=3时, 需传参
     */
    @JSONField(name = "cityname")
    private String cityName;

    /**
     * 区 <br>
     * awardType=3时, 需传参
     */
    @JSONField(name = "districtname")
    private String districtName;

    /**
     * 详细地址 <br>
     * awardType=3时, 需传参
     */
    private String address;

    /**
     * 邮编 <br>
     * awardType=3时, 需传参
     */
    private String zipcode;

    /**
     * 收货人姓名 <br>
     * awardType=3时, 需传参
     */
    @JSONField(name = "consigneename")
    private String consigneeName;

    /**
     * 联系电话 <br>
     * awardType=3时, 需传参
     */
    private String telephone;

    /**
     * 商品编号 <br>
     * awardType=2,3时, 需传参
     */
    @JSONField(name = "goodsid")
    private String goodsId;

    /**
     * 备注 <br>
     * awardType=2,3时, 需传参
     */
    private String summary;

    public String getTransTypeNo() {
        return transTypeNo;
    }

    public void setTransTypeNo(String transTypeNo) {
        this.transTypeNo = transTypeNo;
    }

    public String getAwardType() {
        return awardType;
    }

    public void setAwardType(String awardType) {
        this.awardType = awardType;
    }

    public String getPointsAmount() {
        return pointsAmount;
    }

    public void setPointsAmount(String pointsAmount) {
        this.pointsAmount = pointsAmount;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public String getDistrictName() {
        return districtName;
    }

    public void setDistrictName(String districtName) {
        this.districtName = districtName;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getZipcode() {
        return zipcode;
    }

    public void setZipcode(String zipcode) {
        this.zipcode = zipcode;
    }

    public String getConsigneeName() {
        return consigneeName;
    }

    public void setConsigneeName(String consigneeName) {
        this.consigneeName = consigneeName;
    }

    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }

    public String getGoodsId() {
        return goodsId;
    }

    public void setGoodsId(String goodsId) {
        this.goodsId = goodsId;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }
}

==> customer-link-project-api-1.0.1-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app86760/dto/AddPointsAndPayOrderDTO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app86760.dto;

import com.alibaba.fastjson.annotation.JSONField;

/**
 * write_your_class_description_here
 *
 * @author xulei
 * @since 1.0.0
 */
public class AddPointsAndPayOrderDTO {

    /**
     * 设备号 <br>
     * 必须
     */
    @JSONField(name = "UDID")
    private String userDeviceId;

    /**
     * 手机号 <br>
     * 必须
     */
    private String phone;

    /**
     * 交易类型 <br>
     * 必须
     */
    @JSONField(name = "transtypeno")
    private String transTypeNo = "4018";

    /**
     * 奖品类型: 苏银豆为1, 虚拟卡为2, 实物为3 <br>
     * 必须
     */
    @JSONField(name = "awardType")
    private String awardType;

    /**
     * 交易金额 <br>
     * awardType=1时, 需传参
     */
    @JSONField(name = "pointsamount")
    private String pointsAmount;

    /**
     * 摘要 <br>
     * 必须
     */
    @JSONField(name = "description")
    private String description;

    /**
     * 省 <br>
     * awardType=3时, 需传参
     */
    @JSONField(name = "provincename")
    private String provinceName;

    /**
     * 市 <br>
     * awardType=3时, 需传参
     */
    @JSONField(name = "cityname")
    private String cityName;

    /**
     * 区 <br>
     * awardType=3时, 需传参
     */
    @JSONField(name = "districtname")
    private String districtName;

    /**
     * 详细地址 <br>
     * awardType=3时, 需传参
     */
    private String address;

    /**
     * 邮编 <br>
     * awardType=3时, 需传参
     */
    private String zipcode;

    /**
     * 收货人姓名 <br>
     * awardType=3时, 需传参
     */
    @JSONField(name = "consigneename")
    private String consigneeName;

    /**
     * 联系电话 <br>
     * awardType=3时, 需传参
     */
    private String telephone;

    /**
     * 商品编号 <br>
     * awardType=2,3时, 需传参
     */
    @JSONField(name = "goodsid")
    private String goodsId;

    /**
     * 备注 <br>
     * awardType=2,3时, 需传参
     */
    private String summary;

    public String getUserDeviceId() {
        return userDeviceId;
    }

    public void setUserDeviceId(String userDeviceId) {
        this.userDeviceId = userDeviceId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getTransTypeNo() {
        return transTypeNo;
    }

    public void setTransTypeNo(String transTypeNo) {
        this.transTypeNo = transTypeNo;
    }

    public String getAwardType() {
        return awardType;
    }

    public void setAwardType(String awardType) {
        this.awardType = awardType;
    }

    public String getPointsAmount() {
        return pointsAmount;
    }

    public void setPointsAmount(String pointsAmount) {
        this.pointsAmount = pointsAmount;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }

    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }

    public String getDistrictName() {
        return districtName;
    }

    public void setDistrictName(String districtName) {
        this.districtName = districtName;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getZipcode() {
        return zipcode;
    }

    public void setZipcode(String zipcode) {
        this.zipcode = zipcode;
    }

    public String getConsigneeName() {
        return consigneeName;
    }

    public void setConsigneeName(String consigneeName) {
        this.consigneeName = consigneeName;
    }

    public String getTelephone() {
        return telephone;
    }

    public void setTelephone(String telephone) {
        this.telephone = telephone;
    }

    public String getGoodsId() {
        return goodsId;
    }

    public void setGoodsId(String goodsId) {
        this.goodsId = goodsId;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }
}
